@@ -5,6 +5,7 @@
 #define __USE_XOPEN_EXTENDED
 #endif
 
+#include <glib.h>
 #include <pthread.h>
 #include <stdbool.h>
 #include <stdio.h>
@@ -12,6 +13,7 @@
 #include <string.h>
 #include "directorytree.h"
 #include "file.h"
+#include "utils.h"
 
 #define MAX_FILES 10000
 
@@ -82,9 +84,9 @@ PlayList deepCopyPlayList(PlayList *originalList);
 
 void deepCopyPlayListOntoList(PlayList *originalList, PlayList *newList);
 
-Node *findPathInPlaylist(char *path, PlayList *playlist);
+Node *findPathInPlaylist(const char *path, PlayList *playlist);
 
-Node *findLastPathInPlaylist(char *path, PlayList *playlist);
+Node *findLastPathInPlaylist(const char *path, PlayList *playlist);
 
 int findNodeInList(PlayList *list, int id, Node **foundNode);
 
