@@ -1,5 +1,13 @@
 #include "search_ui.h"
 
+/*
+
+search_ui.c
+
+ Search UI functions.
+
+*/
+
 #define MAX_SEARCH_LEN 32
 
 int numSearchLetters = 0;
@@ -15,18 +23,18 @@ typedef struct SearchResult
 SearchResult *results = NULL;
 size_t resultsCount = 0;
 size_t resultsCapacity = 0;
-bool newUndisplayedSearch = false;
+
 int minSearchLetters = 1;
 FileSystemEntry *currentSearchEntry = NULL;
 
 char searchText[MAX_SEARCH_LEN * 4 + 1]; // unicode can be 4 characters
 
-FileSystemEntry *getCurrentSearchEntry()
+FileSystemEntry *getCurrentSearchEntry(void)
 {
         return currentSearchEntry;
 }
 
-int getSearchResultsCount()
+int getSearchResultsCount(void)
 {
         return resultsCount;
 }
@@ -51,7 +59,7 @@ void collectResult(FileSystemEntry *entry, int distance)
 }
 
 // Free allocated memory from previous search
-void freeSearchResults()
+void freeSearchResults(void)
 {
         if (results != NULL)
         {
@@ -70,7 +78,7 @@ void fuzzySearch(FileSystemEntry *root, int threshold)
         {
                 fuzzySearchRecursive(root, searchText, threshold, collectResult);
         }
-        newUndisplayedSearch = true;
+        refresh = true;
 }
 
 int compareResults(const void *a, const void *b)
@@ -80,16 +88,21 @@ int compareResults(const void *a, const void *b)
         return resultA->distance - resultB->distance;
 }
 
-void sortResults()
+void sortResults(void)
 {
         qsort(results, resultsCount, sizeof(SearchResult), compareResults);
 }
 
-int displaySearchBox(int indent)
+int displaySearchBox(int indent, UISettings *ui)
 {
+        if (ui->useConfigColors)
+                setTextColor(ui->mainColor);
+        else
+                setColor(ui);
+
         printBlankSpaces(indent);
         printf(" [Search]: ");
-        setDefaultTextColor();   
+        setDefaultTextColor();
         // Save cursor position
         printf("%s", searchText);
         printf("\033[s");
@@ -105,10 +118,10 @@ int addToSearchText(const char *str)
                 return -1;
         }
 
-        size_t len = strlen(str);
+        size_t len = strnlen(str, MAX_SEARCH_LEN);
 
         // Check if the string can fit into the search text buffer
-        if (numSearchLetters + 1 > MAX_SEARCH_LEN)
+        if (numSearchLetters + len > MAX_SEARCH_LEN)
         {
                 return 0; // Not enough space
         }
@@ -152,7 +165,7 @@ int getLastCharBytes(const char *str, int len)
 }
 
 // Remove the preceding character from the search text
-int removeFromSearchText()
+int removeFromSearchText(void)
 {
         if (numSearchLetters == 0)
                 return 0;
@@ -200,13 +213,14 @@ int removeFromSearchText()
         return 0;
 }
 
-int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startSearchIter)
+int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startSearchIter, UISettings *ui)
 {
         int term_w, term_h;
         getTermSize(&term_w, &term_h);
 
         int maxNameWidth = term_w - indent - 5;
         char name[maxNameWidth + 1];
+        int printedRows = 0;
 
         sortResults();
 
@@ -230,6 +244,7 @@ int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startS
                 startSearchIter = *chosenRow = 0;
 
         printf("\n");
+        printedRows++;
 
         // Print the sorted results
         for (size_t i = startSearchIter; i < resultsCount; i++)
@@ -237,7 +252,7 @@ int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startS
                 if (numSearchLetters < minSearchLetters)
                         break;
 
-                if ((int)i >= (maxListSize + startSearchIter))
+                if ((int)i >= maxListSize + startSearchIter - 1)
                         break;
 
                 setDefaultTextColor();
@@ -250,10 +265,10 @@ int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startS
 
                         if (results[i].entry->isEnqueued)
                         {
-                                if (useProfileColors)
-                                        setTextColor(enqueuedColor);
+                                if (ui->useConfigColors)
+                                        setTextColor(ui->enqueuedColor);
                                 else
-                                        setColor();
+                                        setColor(ui);
                                 printf("\x1b[7m * ");
                         }
                         else
@@ -265,10 +280,10 @@ int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startS
                 {
                         if (results[i].entry->isEnqueued)
                         {
-                                if (useProfileColors)
-                                        setTextColor(enqueuedColor);
+                                if (ui->useConfigColors)
+                                        setTextColor(ui->enqueuedColor);
                                 else
-                                        setColor();
+                                        setColor(ui);
                                 printf(" * ");
                         }
                         else
@@ -279,21 +294,36 @@ int displaySearchResults(int maxListSize, int indent, int *chosenRow, int startS
                 name[0] = '\0';
                 if (results[i].entry->isDirectory)
                 {
-                        snprintf(name, maxNameWidth + 1, "[%s]", results[i].entry->name);        
-                }       
+                        if (results[i].entry->parent != NULL && strcmp(results[i].entry->parent->name, "root") != 0)
+                                snprintf(name, maxNameWidth + 1, "[%s] (%s)", results[i].entry->name, results[i].entry->parent->name);
+                        else
+                                snprintf(name, maxNameWidth + 1, "[%s]", results[i].entry->name);
+
+                }
                 else
-                {         
-                        snprintf(name, maxNameWidth + 1, "%s", results[i].entry->name);
+                {
+                        if (results[i].entry->parent != NULL && strcmp(results[i].entry->parent->name, "root") != 0)
+                                snprintf(name, maxNameWidth + 1, "%s (%s)", results[i].entry->name, results[i].entry->parent->name);
+                        else
+                                snprintf(name, maxNameWidth + 1, "%s", results[i].entry->name);
                 }
                 printf("%s\n", name);
+                printedRows++;
         }
-        return 0;
-}
 
-int displaySearch(int maxListSize, int indent, int *chosenRow, int startSearchIter)
-{     
-        displaySearchBox(indent);
-        displaySearchResults(maxListSize, indent, chosenRow, startSearchIter);
+        while (printedRows < maxListSize)
+        {
+                printf("\n");
+                printedRows++;
+        }
+
+        return 0;
+}
+
+int displaySearch(int maxListSize, int indent, int *chosenRow, int startSearchIter, UISettings *ui)
+{
+        displaySearchBox(indent, ui);
+        displaySearchResults(maxListSize, indent, chosenRow, startSearchIter, ui);
 
         return 0;
 }
