@@ -16,13 +16,12 @@
 #include <sys/select.h>
 #include <termios.h>
 #include <unistd.h>
+#include "utils.h"
 
 #ifdef __GNU__
 # define _BSD_SOURCE
 #endif
 
-extern volatile sig_atomic_t resizeFlag;
-
 void setTextColor(int color);
 
 void setTextColorRGB(int r, int g, int b);
@@ -53,10 +52,6 @@ void clearRestOfScreen(void);
 
 void enableScrolling(void);
 
-void handleResize(int sig);
-
-void resetResizeFlag(int sig);
-
 void initResize(void);
 
 void disableInputBuffering(void);
@@ -71,10 +66,4 @@ void clearScreen(void);
 
 int readInputSequence(char *seq, size_t seqSize);
 
-int isFunctionKey(const char *seq);
-
-void convertControlNotationToAscii(char *input, char *output, size_t size);
-
-void convertAsciiToControlNotation(char input, char *output, size_t size);
-
 #endif
